# Realms - the simplest Python game engine

Realms is an open-source game engine.

Our goal? To provide a simple yet incredibly powerful game engine, written entirely in Python.

This library is written on top of the [pygame](https://pypi.org/project/pygame) library.

## Documentation

You can view the full documentation [on GitBook](https://dcoded.gitbook.io/realms).


You can view the documentation for Realms [on GitBook](https://dcoded.gitbook.io/realms).
